@@ -41,7 +41,7 @@ from aea.configurations.base import PackageConfiguration, PackageType
 from aea.configurations.constants import PACKAGE_TYPE_TO_CONFIG_FILE, SCAFFOLD_PACKAGES
 from aea.configurations.data_types import PackageId, PublicId
 from aea.configurations.loader import load_configuration_object
-from aea.helpers.dependency_tree import DependecyTree, dump_yaml, load_yaml
+from aea.helpers.dependency_tree import DependencyTree, dump_yaml, load_yaml
 from aea.helpers.fingerprint import update_fingerprint
 from aea.helpers.io import to_csv
 
@@ -81,7 +81,7 @@ def update_hashes(  # pylint: disable=too-many-locals
 
     try:
         public_id_to_hash_mappings: Dict = {}
-        dependency_tree = DependecyTree.generate(packages_dir)
+        dependency_tree = DependencyTree.generate(packages_dir)
         packages = [
             [package_id_and_path(package_id, packages_dir) for package_id in tree_level]
             for tree_level in dependency_tree
