@@ -235,7 +235,7 @@ spec:
             name: nodes
 
       - name: aea
-        image: {open_aea_image_name}:{valory_app}-{open_aea_image_version}
+        image: {runtime_image}
         imagePullPolicy: Always
         resources:
           limits:
