@@ -41,7 +41,8 @@ from autonomy.constants import (
 from autonomy.deploy.base import BaseDeploymentGenerator, ServiceSpecification
 from autonomy.deploy.generators.docker_compose.base import DockerComposeGenerator
 from autonomy.deploy.generators.kubernetes.base import KubernetesGenerator
-from autonomy.test_tools.docker.base import skip_docker_tests
+
+from tests.conftest import skip_docker_tests
 
 
 deployment_generators: List[Any] = [
