@@ -24,12 +24,11 @@ from typing import Generator, Tuple
 
 import pytest
 from aea.configurations.data_types import PublicId
-
-from autonomy.test_tools.base_test_classes.agents import (
+from aea_test_autonomy.base_test_classes.agents import (
     BaseTestEnd2End,
     BaseTestEnd2EndExecution,
 )
-from autonomy.test_tools.fixture_helpers import UseACNNode, UseGnosisSafeHardHatNet
+from aea_test_autonomy.fixture_helpers import UseACNNode, UseRegistries
 
 from packages.valory.skills.registration_abci.behaviours import (
     RegistrationStartupBehaviour,
@@ -61,9 +60,7 @@ STRICT_CHECK_STRINGS = (
 )
 
 
-class RegistrationStartUpTestConfig(
-    UseGnosisSafeHardHatNet, UseACNNode, BaseTestEnd2End
-):
+class RegistrationStartUpTestConfig(UseRegistries, UseACNNode, BaseTestEnd2End):
     """Base class for e2e tests using the ACN client connection"""
 
     skill_package = "valory/registration_abci:0.1.0"
