@@ -23,15 +23,30 @@ import itertools
 from pathlib import Path
 from typing import List
 
+import _strptime  # noqa  # pylint: disable=unsed-import
 import pytest
 from aea.components.base import load_aea_package
-from aea.configurations.base import PACKAGE_TYPE_TO_CONFIG_CLASS
 from aea.configurations.constants import PACKAGES, PACKAGE_TYPE_TO_CONFIG_FILE
 from aea.configurations.data_types import PackageType
 from aea.configurations.loader import ConfigLoader
 from aea.helpers.io import open_file
+from aea_test_autonomy.configurations import (
+    DEFAULT_IMAGE_VERSION as PLUGIN_DEFAULT_IMAGE_VERSION,
+)
+from aea_test_autonomy.configurations import (
+    TENDERMINT_IMAGE_NAME as PLUGIN_TENDERMINT_IMAGE_NAME,
+)
+from aea_test_autonomy.configurations import (
+    TENDERMINT_IMAGE_VERSION as PLUGIN_TENDERMINT_IMAGE_VERSION,
+)
 
 import autonomy
+from autonomy.configurations.base import PACKAGE_TYPE_TO_CONFIG_CLASS
+from autonomy.constants import (
+    DEFAULT_IMAGE_VERSION,
+    TENDERMINT_IMAGE_NAME,
+    TENDERMINT_IMAGE_VERSION,
+)
 
 from tests.conftest import ROOT_DIR
 
@@ -60,6 +75,7 @@ def test_version() -> None:
                 (get_test_files(PackageType.CONTRACT), PackageType.CONTRACT),
                 (get_test_files(PackageType.CONNECTION), PackageType.CONNECTION),
                 (get_test_files(PackageType.SKILL), PackageType.SKILL),
+                (get_test_files(PackageType.SERVICE), PackageType.SERVICE),
             ]
         ]
     ),
@@ -72,6 +88,16 @@ def test_load_all_packages(component_type: PackageType, config_file_path: str) -
     )
     with open_file(config_file_path) as fp:
         configuration_object = configuration_loader.load(fp)
-        directory = Path(config_file_path).parent
-        configuration_object.directory = directory
-        load_aea_package(configuration_object)
+        if component_type != PackageType.SERVICE:
+            # we don't need to check sub packages for service components
+            # so we perform `load_aea_package` only for none service components
+            directory = Path(config_file_path).parent
+            configuration_object.directory = directory
+            load_aea_package(configuration_object)
+
+
+def test_synced_with_plugins() -> None:
+    """Test plugin and autonomy constants are synced."""
+    assert DEFAULT_IMAGE_VERSION == PLUGIN_DEFAULT_IMAGE_VERSION
+    assert TENDERMINT_IMAGE_NAME == PLUGIN_TENDERMINT_IMAGE_NAME
+    assert TENDERMINT_IMAGE_VERSION == PLUGIN_TENDERMINT_IMAGE_VERSION
