@@ -23,12 +23,23 @@ from unittest import TestCase
 import pytest
 
 from tests.test_connections.test_fuzz.base import BaseFuzzyTests
+from tests.test_connections.test_fuzz.mock_node.channels.grpc_channel import GrpcChannel
 from tests.test_connections.test_fuzz.mock_node.channels.tcp_channel import TcpChannel
 
 
-@pytest.mark.skip(reason="takes too long time to complete on CI")
+@pytest.mark.skip(reason="broken & takes too long time to complete on CI")
+class GrpcFuzzyTests(BaseFuzzyTests, TestCase):
+    """Test the connection when gRPC is used"""
+
+    CHANNEL_TYPE = GrpcChannel
+    USE_GRPC = True
+    AGENT_TIMEOUT = 30  # 3 seconds
+
+
+@pytest.mark.skip(reason="broken & takes too long time to complete on CI")
 class TcpFuzzyTests(BaseFuzzyTests, TestCase):
     """Test the connection when TCP is used"""
 
     CHANNEL_TYPE = TcpChannel
+    USE_GRPC = False
     AGENT_TIMEOUT = 30  # 3 seconds
